@@ -11,7 +11,7 @@ See `CircuitPython:board` in CircuitPython for more details.
 """
 
 
-__version__ = "8.62.0"
+__version__ = "8.66.2"
 __repo__ = "https://github.com/adafruit/Adafruit_Blinka.git"
 __blinka__ = True
 
@@ -146,6 +146,9 @@ elif board_id == ap_board.ORANGE_PI_4_LTS:
 elif board_id in (ap_board.ORANGE_PI_5, ap_board.ORANGE_PI_5_MAX):
     from adafruit_blinka.board.orangepi.orangepi5 import *
 
+elif board_id == ap_board.ORANGE_PI_5_PRO:
+    from adafruit_blinka.board.orangepi.orangepi5pro import *
+
 elif board_id == ap_board.ORANGE_PI_5_PLUS:
     from adafruit_blinka.board.orangepi.orangepi5plus import *
 
@@ -206,6 +209,9 @@ elif board_id == ap_board.JETSON_AGX_ORIN:
 elif board_id in (ap_board.JETSON_ORIN_NX, ap_board.JETSON_ORIN_NANO):
     from adafruit_blinka.board.nvidia.jetson_orin_nx import *
 
+elif board_id == ap_board.JETSON_THOR:
+    from adafruit_blinka.board.nvidia.jetson_thor import *
+
 elif board_id == ap_board.CLARA_AGX_XAVIER:
     from adafruit_blinka.board.nvidia.clara_agx_xavier import *
 
@@ -467,6 +473,9 @@ elif board_id == ap_board.INDIEDROID_NOVA:
 elif board_id == ap_board.RDK_X3:
     from adafruit_blinka.board.horizon.rdkx3 import *
 
+elif board_id == ap_board.PARTICLE_TACHYON:
+    from adafruit_blinka.board.particle.tachyon import *
+
 elif "sphinx" in sys.modules:
     pass
 
